## Remote sources

- [ ] describe the main logic
  - remote <-> local folder


## Available sources

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/remote.py#L278)</span>
### GitLFSSource

```python
kipoi.remote.GitLFSSource(remote_url, local_path)
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/remote.py#L372)</span>
### GitSource

```python
kipoi.remote.GitSource(remote_url, local_path)
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/remote.py#L438)</span>
### LocalSource

```python
kipoi.remote.LocalSource(local_path)
```

